# Monasterium to-CEI converter

Models a CEI charters and charter groups as python objects with the ability to
serialize to xml files ready to be imported into Monasterium.net.

## Installing

Install by executing `pip install to_cei`.

## Building

Build by executing `python -m build`.

## Testing

Launch tests with `pytest`.
